//Ozzy0421



/****************************************************************************
 * This is an example for the use of Audeme's MOVI(tm) Voice Control Shield *
 * ----> http://www.audeme.com/MOVI/                                        *
 * This code is inspired and maintained by Audeme but open to change        *
 * and organic development on GITHUB:                                       *
 * ----> https://github.com/audeme/MOVIArduinoAPI                           *
 * Written by Gerald Friedland for Audeme LLC.                              *
 * Contact: fractor@audeme.com                                              *
 * BSD license, all text above must be included in any redistribution.      *
 ****************************************************************************
 *
 * This basic example shows how to use MOVI(tm)'s API to train the call 
 * sign "Arduino" and two sentences. When the sentences are recognized
 * they switch on and off an LED on PIN D13. Many boards have a hardwired 
 * LED on board already connected to D13.
 *
 * Circuitry:
 * LED is pin D13 and GND
 * Arduino UNO R3, MEGA2560 R3, or Arduino Leonardo R3.
 * Connect speaker to MOVI.
 * IMPORTANT: Always use external power supply with MOVI. 
 * 
 * Other Arduino-compatible boards:  
 * Consult MOVI's User Manual before connecting MOVI.
 *
 * If you long-press the button on the MOVI (for a couple seconds), 
 * MOVI will revert back to the call sign and sentences trained here.
 */

#include "MOVIShield.h"     // Include MOVI library, needs to be *before* the next #include

#ifdef ARDUINO_ARCH_AVR 
#include <SoftwareSerial.h> // This is nice and flexible but only supported on AVR architecture, other boards need to use Serial1 
#endif

const int led = 13;
MOVI recognizer(true);            // Get a MOVI object, true enables serial monitor interface, rx and tx can be passed as parameters for alternate communication pins on AVR architecture

void setup()  
{
  pinMode(led, OUTPUT);    // Make LED port writeable
  digitalWrite(led, HIGH); // Blink LED.   
  delay(1);                   
  digitalWrite(led, LOW);  
  delay(1); 

  pinMode(8,OUTPUT);//make pin output
  pinMode(7,OUTPUT);//make pin output
  pinMode(6,OUTPUT);//pin for "come here"

  recognizer.init();      // Initialize MOVI (waits for it to boot)

  //*
  // Note: training can only be performed in setup(). 
  // The training functions are "lazy" and only do something if there are changes. 
  // They can be commented out to save memory and startup time once training has been performed.
  recognizer.callSign("Ozzy"); // Train callsign Arduino (may take 20 seconds)
  recognizer.addSentence("Go forward"); // Add sentence 1
  recognizer.addSentence("Go right");            // Add sentence 2
  recognizer.addSentence("Go left");//add sentence 3
  recognizer.addSentence("Come here");//add sentence 4
  recognizer.train();                           // Train (may take 20seconds) 
  //*/

  //  recognizer.setThreshold(5);			// uncomment and set to a higher value (valid range 2-95) if you have a problems due to a noisy environment.
}

void loop() // run over and over
{
  signed int res=recognizer.poll(); // Get result from MOVI, 0 denotes nothing happened, negative values denote events (see docs)
  if (res==1) {                     // Sentence 1.
    digitalWrite(8, HIGH);        // Turn on LED
    //recognizer.say("and there was light!"); // Speak a sentence
    delay(1000);
    digitalWrite(8,LOW);
  } 
  if (res==2) {                    // Sentence 2 
    digitalWrite(7, HIGH);        // Turn on LED
    delay(1000);
    digitalWrite(7,LOW);
  }
 
  if (res==3) {//sentence 3
    digitalWrite(led,HIGH);
    delay(1000);
    digitalWrite(led,LOW);
   

    
  }

  if (res==4) {//"come here"
    digitalWrite(6,HIGH);
    delay(1000);
    digitalWrite(6,LOW);
  }
  

  
  // Do more ...
}
